@@ -8,6 +8,7 @@ LANGUAGES = {
     'cs': 'C#',
     'c': 'C',
     'py': 'Python',
+    'py_nl': 'Python (no lint)',
     'py2': 'Python 2',
     'rb': 'Ruby',
     'js': 'JavaScript',
@@ -33,7 +34,7 @@ EXEC_COMMANDS = {
     'c': lambda filename: [filename],
     'py': lambda filename: ['python3', filename],
     'py_nl': lambda filename: ['python3', filename],
-    'py2': lambda filename: ['python2', filename]
+    'py2': lambda filename: ['python2', filename],
     'rb': lambda filename: ['ruby', filename],
     'js': lambda filename: ['node', filename],
     'rs': lambda filename: [filename],
@@ -46,7 +47,7 @@ AVAILABLE_BINARIES = {
     'c': ['gcc', 'ld', 'as'],
     'py': ['python', 'python3', 'pylint', 'cp'],
     'py_nl': ['python', 'python3', 'cp'],
-    'py2': ['python2', 'cp']
+    'py2': ['python2', 'cp'],
     'rb': ['ruby', 'cp'],
     'js': ['node', 'cp'],
     'rs': ['rustc', 'cc', 'ld'],
